# -*- coding: utf-8 -*-
# Copyright 2020 Cohesity Inc.

class EnvironmentListProtectionSourcesEnum(object):

    """Implementation of the 'environment_ListProtectionSources' enum.

    TODO: type enum description here.

    Attributes:
        KVMWARE: TODO: type description here.
        KSQL: TODO: type description here.
        KVIEW: TODO: type description here.
        KPUPPETEER: TODO: type description here.
        KPHYSICAL: TODO: type description here.
        KPURE: TODO: type description here.
        KNETAPP: TODO: type description here.
        KGENERICNAS: TODO: type description here.
        KHYPERV: TODO: type description here.
        KACROPOLIS: TODO: type description here.
        KAZURE: TODO: type description here.
        KKUBERNETES: TODO: type description here.

    """

    K_VMWARE = 'kVMware'

    KSQL = 'kSQL'

    KVIEW = 'kView'

    KPUPPETEER = 'kPuppeteer'

    KPHYSICAL = 'kPhysical'

    KPURE = 'kPure'

    KNETAPP = 'kNetapp'

    KGENERICNAS = 'kGenericNas'

    K_HYPERV = 'kHyperV'

    KACROPOLIS = 'kAcropolis'

    KAZURE = 'kAzure'

    KKUBERNETES = 'kKubernetes'

